function res=opt_ozon(lambda,DU)
% ozone optical thickness
% requires ozon.dat file
% input: 
%       lambda - wavelength in nm
%       DU - total ozon  in Dobson  unit
% output:
%        res - ozone opticak thicknes  
x=lambda/1000;
DUnew=DU/1000;
load ozon.dat
a_ozon=interp1(ozon(:,1),ozon(:,2),x);  % calculate absorbion coeff [1/cm]
res=a_ozon*DUnew;
a=isnan(res);
res(a)=0;
ind=find(lambda<350);
if isempty(ind)==0
 for k=1:length(DU)
  res(ind,k)=2.1349e19*exp(-0.14052*lambda(ind))*DUnew(k);
 end
end 
